Learn R Programming

LBBNN (version 0.1.2)

Raisin_Dataset: Raisins Dataset

Description

Ilkay Cinar, Murat Kokl and Sakir Tasdemi(2020) provide a dataset consisting of 2 varieties of Turkish raisins, with 450 samples of each type. The dataset contains 7 morphological features, extracted from images taken of the Raisins. The goal is to classify to one of the two types of Raisins.

Usage

Raisin_Dataset

Arguments

Format

this data frame has 900 rows and the following 8 columns:

Area

Number of pixels within the boundary

MajorAxisLength

Length of the main axis

MinorAxisLength

Length of the small axis

Eccentricity

Measure of the eccentricity of the ellipse

ConvexArea

The number of pixels of the smallest convex shell of the region formed by the raisin grain

Extent

Ratio of the region formed by the raisin grain to the total pixels in the bounding box

Perimeter

distance between the boundaries of the raisin grain and the pixels around it

Class

Kecimen or Besni raisin.