Learn R Programming

LBBNN (version 0.1.2)

alpha_prior: Generate prior inclusion probabilities for the weights of a LBBNN layer (linear or convolutional).

Description

A function to generate prior probability values for each weight in an LBBNN layer. The same probability is applied to all weights within a layer.

Usage

alpha_prior(x)

Value

a numeric to be added to either (out_shape,in_shape) in case of linear layers or (out_channels,in_channels,kernel0,kernel1) in case of convolutional layers.

Arguments

x

A number between 0 and 1.