Learn R Programming

LBBNN (version 0.1.2)

assign_names: Assign names to nodes.

Description

Internal helper function to assign descriptive names to nodes used for plotting.

Usage

assign_names(model)

Value

A list of adjacency matrices with the correct names.

Arguments

model

A trained LBBNN_Net model with input-skip.