Learn R Programming

LBBNN (version 0.1.2)

get_adj_mats: Obtain adjacency matrices for igraph plotting

Description

Takes the alpha active path matrices for each layer of the LBBNN and converts them to adjacency matrices so that they can be plotted with igraph.

Usage

get_adj_mats(model)

Value

A list of adjacency matrices, one for each hidden layer and the output layer.

Arguments

model

An instance of LBBNN_Net with input_skip enabled.