Latent binary Bayesian neural networks (LBBNNs) are implemented using 'torch', an R interface to the LibTorch backend. Supports mean-field variational inference as well as flexible variational posteriors using normalizing flows. The standard LBBNN implementation follows Hubin and Storvik (2024) tools:::Rd_expr_doi("10.3390/math12060788"), using the local reparametrization trick as in Skaaret-Lund et al. (2024) https://openreview.net/pdf?id=d6kqUKzG3V. Input-skip connections are also supported, as described in Høyheim et al. (2025) tools:::Rd_expr_doi("10.48550/arXiv.2503.10496").
Maintainer: Lars Skaaret-Lund lars.skaaret-lund@nmbu.no
Authors:
Aliaksandr Hubin aliaksandr.hubin@nmbu.no
Eirik Høyheim eirik.hoyheim@ffi.no