Ilkay Cinar, Murat Kokl and Sakir Tasdemi(2020) provide a dataset consisting of 2 varieties of Turkish raisins, with 450 samples of each type. The dataset contains 7 morphological features, extracted from images taken of the Raisins. The goal is to classify to one of the two types of Raisins.
Raisin_Datasetthis data frame has 900 rows and the following 8 columns:
Number of pixels within the boundary
Length of the main axis
Length of the small axis
Measure of the eccentricity of the ellipse
The number of pixels of the smallest convex shell of the region formed by the raisin grain
Ratio of the region formed by the raisin grain to the total pixels in the bounding box
distance between the boundaries of the raisin grain and the pixels around it
Kecimen or Besni raisin.