A function to generate prior probability values for each weight in an LBBNN layer. The same probability is applied to all weights within a layer.
alpha_prior(x)a numeric to be added to either (out_shape,in_shape) in case of linear layers or (out_channels,in_channels,kernel0,kernel1) in case of convolutional layers.
A number between 0 and 1.