powered by
Internal helper function to assign descriptive names to nodes used for plotting.
assign_names(model)
A list of adjacency matrices with the correct names.
A trained LBBNN_Net model with input-skip.
LBBNN_Net