powered by
igraph
Takes the alpha active path matrices for each layer of the LBBNN and converts them to adjacency matrices so that they can be plotted with igraph.
get_adj_mats(model)
A list of adjacency matrices, one for each hidden layer and the output layer.
An instance of LBBNN_Net with input_skip enabled.
LBBNN_Net